@@ -33,7 +33,7 @@ class init_anim:
     def __init__(self, t, speed_up, scale):
 
         """
-        Sets up the global animation information such speed up and global scale
+        .. Sets up the global animation information such speed up and global scale
 
 
         Arguments:
@@ -67,7 +67,7 @@ class init_anim:
 class ref_frame:
     def __init__(self, name, parent, anim):
         """
-        Initializes a reference frame that other objects and animations can be the child of. 
+        .. Initializes a reference frame that other objects and animations can be the child of. 
 
         In blender, this takes the form of an Empty object.
 
@@ -102,9 +102,12 @@ class ref_frame:
         
     def static_6DOF(self, quat, x, y, z):
         """
-        INTERNAL METHOD Places the reference frame in one specified static location.
+        .. Places the reference frame in one specified static location.
+
+        .. warning::
+            This is currently an internal method. This method will be exposed properly in future updates
+        .. versionadded:: 0.2.30
 
-        This method will be properly exposed in future updates.
         May be useful for offsetting the reference frame from the parent object (i.e. for center of mass of principal axes offset)
 
 
@@ -127,9 +130,12 @@ class ref_frame:
         
     def dynamic_6DOF(self, quat, x_list, y_list, z_list):
         """
-        INTERNAL METHOD Animates the reference frame over time.
+        .. Animates the reference frame over time.
+
+        .. warning::
+            This is currently an internal method. This method will be exposed properly in future updates
+        .. versionadded:: 0.2.30
 
-        This method will be properly exposed in future updates.
         May be useful for continually offsetting the reference frame from the parent object (i.e. for center of mass of principal axes offset for changing mass/distribution)
 
 
@@ -171,7 +177,7 @@ class dyn_obj:
     def __init__(self, obj, pa, euler_type, parent, anim):
 
         """
-        The main building block of all dynamic visualizations 
+        .. The main building block of all dynamic visualizations 
 
         Arguments:
             :param obj (bpy.data.object): the Blender object that will be animated
@@ -221,7 +227,7 @@ class dyn_obj:
     def apply_animation(self, x_list, y_list, z_list, quat_list):
 
         """
-        Animates a :class:`~bpsci.core.dyn_obj` in the full six degrees of freedom
+        .. Animates a :class:`~bpsci.core.dyn_obj` in the full six degrees of freedom
 
         Arguments:
         :param x_list (nd.array): a numpy array of the x position over time
@@ -235,7 +241,7 @@ class dyn_obj:
 
     def apply_streamline(self, staticity, int_x, int_y, int_z, thickness):
         """
-        Creates a static or dynamic positional streamline for a :class:`~bpsci.core.dyn_obj`
+        .. Creates a static or dynamic positional streamline for a :class:`~bpsci.core.dyn_obj`
 
         Arguments:
             :param staticity (str): a string (either 'static' or 'dynamic') that specifies whether the the streamline is animated over time
@@ -290,7 +296,7 @@ class dyn_obj:
 class dyn_vec:
     def __init__(self, parent, name, scale_mag, scale_off, offset, anim):
         """
-        Initializes a dynamic vector`
+        .. Initializes a dynamic vector`
 
         Arguments:
             :param parent (bpy.data.object): the Blender object the vector is associated with
@@ -333,7 +339,7 @@ class dyn_vec:
         """iterable[float]: the frames that Blender will animate and have corresponding data for"""
     def animate(self, x, y, z):
         """
-        Animates a dynamic vector
+        .. Animates a dynamic vector
 
         Arguments:
         :param x (nd.array): a numpy array of the x component over time
@@ -383,7 +389,7 @@ class dyn_vec:
 class anim_text:
     def __init__(self, name, parent, anim, data, label, fix_place, if_str):
         """
-        Creates animated text
+        .. Creates animated text
 
         Arguments:
         :param name (str): the Blender object name of the text ('_text' will be appended to this name)
